categories <-function(){
list(continuous="Models for Continuous Dependent Variables",
     dichotomous="Models for Dichotomous Dependent Variables",
     ordinal="Models for Ordinal Dependent Variables",
     bounded="Models for Continous Bounded Dependent Variables",
     multinomial="Multinomial Choice Models",
     count="Event Count Models",
     mixed="Models for Mixed Dependent Variables",
     ei="Ecological Inference Models")
}
